/*
 * Copyright (C) The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.belvi.mobilevisionbarcodesample;

import android.os.Bundle;
import android.support.v7.app.AlertDialog;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.SwitchCompat;
import android.util.Log;
import android.util.SparseArray;
import android.view.View;
import android.widget.CheckBox;

import com.google.android.gms.samples.vision.barcodereader.BarcodeCapture;
import com.google.android.gms.samples.vision.barcodereader.BarcodeGraphic;
import com.google.android.gms.vision.CameraSource;
import com.google.android.gms.vision.barcode.Barcode;

import java.util.List;
import java.util.ArrayList;

import xyz.belvi.mobilevisionbarcodescanner.BarcodeRetriever;

import static xyz.belvi.mobilevisionbarcodescanner.R.id.barcode;
import xyz.belvi.mobilevisionbarcodescanner.R;
import anywheresoftware.b4a.BA;

/**
 * Main activity demonstrating how to pass extra parameters to an activity that
 * reads barcodes.
 */
public class MainActivity extends AppCompatActivity implements BarcodeRetriever {

    // use a compound button so either checkbox or switch widgets work.


    private static final String TAG = "BarcodeMain";
	public static List<String> list;

    CheckBox fromXMl, pause;
    SwitchCompat drawRect, autoFocus, supportMultiple, touchBack, drawText, flash, frontCam;

    BarcodeCapture barcodeCapture;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        BA.Log("In onCreate of MainActivity");
		list = new ArrayList<String>();

        barcodeCapture = (BarcodeCapture) getSupportFragmentManager().findFragmentById(barcode);
        barcodeCapture.setRetrieval(this);

        fromXMl = (CheckBox) findViewById(R.id.from_xml);
		fromXMl.toggle();


        pause = (CheckBox) findViewById(R.id.pause);
		pause.toggle();

        drawRect = (SwitchCompat) findViewById(R.id.draw_rect);
		drawRect.toggle();
		barcodeCapture.setShowDrawRect(drawRect.isChecked());

        autoFocus = (SwitchCompat) findViewById(R.id.focus);
		autoFocus.toggle();
        supportMultiple = (SwitchCompat) findViewById(R.id.support_multiple);
		supportMultiple.toggle();
        touchBack = (SwitchCompat) findViewById(R.id.touch_callback);
//		touchBack.toggle();
        drawText = (SwitchCompat) findViewById(R.id.draw_text);
		drawText.toggle();
        flash = (SwitchCompat) findViewById(R.id.on_flash);
        frontCam = (SwitchCompat) findViewById(R.id.front_cam);
		
                    barcodeCapture.setShowDrawRect(drawRect.isChecked())
                            .setSupportMultipleScan(supportMultiple.isChecked())
                            .setTouchAsCallback(touchBack.isChecked())
                            .shouldAutoFocus(autoFocus.isChecked())
                            .setShowFlash(flash.isChecked())
                            .setShowFlash(flash.isChecked())
                            .setBarcodeFormat(Barcode.ALL_FORMATS)
                            .setCameraFacing(frontCam.isChecked() ? CameraSource.CAMERA_FACING_FRONT : CameraSource.CAMERA_FACING_BACK)
                            .setShouldShowText(drawText.isChecked());		
		
		barcodeCapture.refresh(true);

        findViewById(R.id.stop).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                barcodeCapture.stopScanning();
            }
        });

        findViewById(R.id.refresh).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                if (fromXMl.isChecked()) {

                } else {
                    barcodeCapture.setShowDrawRect(drawRect.isChecked())
                            .setSupportMultipleScan(supportMultiple.isChecked())
                            .setTouchAsCallback(touchBack.isChecked())
                            .shouldAutoFocus(autoFocus.isChecked())
                            .setShowFlash(flash.isChecked())
                            .setShowFlash(flash.isChecked())
                            .setBarcodeFormat(Barcode.ALL_FORMATS)
                            .setCameraFacing(frontCam.isChecked() ? CameraSource.CAMERA_FACING_FRONT : CameraSource.CAMERA_FACING_BACK)
                            .setShouldShowText(drawText.isChecked());
                    if (pause.isChecked())
                        barcodeCapture.pause();
                    else
                        barcodeCapture.resume();
                    barcodeCapture.refresh(true);
                }
            }
        });

    }


    @Override
    public void onRetrieved(final Barcode barcode) {
        Log.d(TAG, "Barcode read: " + barcode.displayValue);
        runOnUiThread(new Runnable() {
            @Override
            public void run() {

            }
        });
        barcodeCapture.stopScanning();


    }

	
	public static String closeToClick = "";
    @Override
    public void onRetrievedMultiple(final Barcode closetToClick, final List<BarcodeGraphic> barcodeGraphics) {
        runOnUiThread(new Runnable() {
            @Override
            public void run() {
                String message = "Code selected : " + closetToClick.displayValue + "\n\nother " +
                        "codes in frame include : \n";
				closeToClick = closetToClick.displayValue;
		
                for (int index = 0; index < barcodeGraphics.size(); index++) {
                    Barcode barcode = barcodeGraphics.get(index).getBarcode();
                    message += (index + 1) + ". " + barcode.displayValue + "\n";
					list.add("" + barcode.format);
					if (barcode.format == 1)
						list.add("CODE_128");
					if (barcode.format == 2)
						list.add("CODE_39");	
					if (barcode.format == 4)
						list.add("CODE_93");		
					if (barcode.format == 8)
						list.add("CODABAR");	
					if (barcode.format == 16)
						list.add("DATA_MATRIX");
					if (barcode.format == 32)
						list.add("EAN_13");	
					if (barcode.format == 64)
						list.add("EAN_8");	
					if (barcode.format == 128)
						list.add("ITF");
					if (barcode.format == 256)
						list.add("QR_CODE");	
					if (barcode.format == 512)
						list.add("UPC_A");		
					if (barcode.format == 1024)
						list.add("UPC_E");	
					if (barcode.format == 2048)
						list.add("PDF417");	
					if (barcode.format == 4096)
						list.add("AZTEC");						
					list.add("" + barcode.displayValue);
                }
				
				finish();
            }
        });

    }

    @Override
    public void onBitmapScanned(SparseArray<Barcode> sparseArray) {
        for (int i = 0; i < sparseArray.size(); i++) {
            Barcode barcode = sparseArray.valueAt(i);
            Log.e("value", barcode.displayValue);
        }

    }

    @Override
    public void onRetrievedFailed(String reason) {

    }

    @Override
    public void onPermissionRequestDenied() {

    }


}
